@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::SHLOMIF;
-our $AUTHORITY = 'cpan:DOY';
-$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000003';
+our $AUTHORITY = 'cpan:SHLOMIF';
+$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000004';
 use Moose;
 # ABSTRACT: Dist::Zilla plugins for me
 
@@ -303,7 +303,7 @@ Dist::Zilla::PluginBundle::SHLOMIF - Dist::Zilla plugins for me
 
 =head1 VERSION
 
-version 0.000003
+version 0.000004
 
 =head1 SYNOPSIS
 
